@@ -1,7 +1,5 @@
-import cython
-import pyximport; pyximport.install()
-import pandas as pd
 import numpy as np
+import pandas as pd
 import xlrd
 import openpyxl
 import PyPDF2
@@ -10,12 +8,13 @@ import os
 import sys
 from io import StringIO
 from math import floor
-from alacorder import run
 from alacorder import alac
+import re
 import warnings
 
 warnings.filterwarnings("ignore")
 
+
 print('''
 
 	    ___    __                          __         
@@ -25,27 +24,27 @@ print('''
 	/_/  |_/_/\\__,_/\\___/\\____/_/   \\__,_/\\___/_/     
 																																														
 		
-		ALACORDER beta 6.4
+		ALACORDER beta 7.0.8 (pure-python)
 		by Sam Robson	
 
 
 Welcome to Alacorder. Please select an operating mode:
 
-A.	EXPORTING DETAILED CASE INFORMATION AS A TABLE
+A.	MAKE A TABLE FROM DIRECTORY OR ARCHIVE
 
 	Create detailed cases table with convictions, charges,
 	fees, and voting rights restoration information. 
 
-	Inputs:		PDF Directory (./path/to/pdfs) or Archive (.pkl, .csv, .xls, .json)
-	Outputs:	Detailed Cases Table (.pkl, .csv, .xls, .dta, .json) or non-importable text file (.txt)
+	Inputs:		Text Archive (.pkl.xz) or PDF directory
+	Outputs:	.csv, .xls, .dta, .json, .txt
 
-B.	CREATE A FULL TEXT ARCHIVE FROM PDF CASES
+B.	ARCHIVE CASE DIRECTORY
 
-	Search directory for PDF files, collect full text and compress into archive.
-	Archives can be processed into tables with mode A or manually with alac.
+	Collect text from PDFs in directory and compress to archive.
+	Archives can be processed into tables upon task completion.
 
 	Inputs:		PDF Directory (./path/to/pdfs)
-	Outputs:	Archive (.pkl, .csv, .xls, .json) or non-importable text file (.txt)
+	Outputs:	filename.pkl.xz
 
 >> Enter A or B:
 ''')
@@ -55,19 +54,19 @@ ab = "".join(input()).strip()
 if ab == "A":
 	print(f'''
 
-	>>	Enter the input PDF directory or archive file path.
-			ex.	/full/path/to/pdf/folder/
-			ex.	/full/path/to/fulltextarchive.pkl
+>>	Enter the input PDF directory or archive file path.
+		ex.	/full/path/to/pdf/folder/
+		ex.	/full/path/to/fulltextarchive.pkl.xz
 
-	>> Input path:
+>> Input path:
 ''')
 elif ab == "B":
 	print(f'''
 
-	>>	Enter the input PDF directory path, including a forward-slash.
-			ex.	/full/path/to/pdf/folder/
+>>	Enter the input PDF directory path, including a forward-slash.
+		ex.	/full/path/to/pdf/folder/
 
-	>> Input path: 
+>> Input path: 
 ''')
 else:
 	raise Exception("Not a valid input!")
@@ -81,20 +80,20 @@ else:
 if ab == "A":
 	print(f'''
 
-	>>	Enter the output file path.
-			ex.	/full/path/to/casestable.xls
-			ex.	/full/path/to/cases.csv
+>>	Enter the output file path.
+		ex.	/full/path/to/casestable.xls
+		ex.	/full/path/to/cases.csv
 
-	>> Output path: 
+>> Output path: 
 ''')
 elif ab == "B":
 	print(f'''
 
-	>>	Enter the output archive file path.
-			ex.	/full/path/to/fulltextarchive.pkl
-			ex.	/path/to/archive.csv
+>>	Enter the output archive file path.
+		ex.	/full/path/to/fulltextarchive.pkl
+		ex.	/path/to/archive.csv
 
-	>> Output path: 
+>> Output path: 
 ''')
 else:
 	raise Exception("Not a valid input!")
@@ -105,7 +104,7 @@ out_ext = xpath.split(".")[-1].strip()
 if ab == "A" and in_ext == "directory":
 	mode = "tables-from-directory"
 	batch_size = 100
-elif ab == "A" and in_ext == "pkl" or in_ext == "json" or in_ext == "csv" or in_ext == "xls":
+elif ab == "A" and in_ext == "pkl" or in_ext == "json" or in_ext == "csv" or in_ext == "xls" or in_ext == "xz":
 	mode = "tables-from-archive"
 	batch_size = 2000
 elif ab == "B" and in_ext == "directory":
@@ -122,11 +121,11 @@ print(f'''
 ''')
 
 if ab == "B":
-	c = run.config(in_dir,xpath)
-	run.writeArchive(c)
+	c = alac.config(in_dir,xpath)
+	alac.writeArchive(c)
 if ab == "A":
-	c = run.config(in_dir,xpath)
-	run.writeTables(c)
+	c = alac.config(in_dir,xpath)
+	alac.writeArchiveThenTables(c)
 
 if mode == "archive-from-directory":
 	print(f'''
@@ -147,9 +146,9 @@ Output Path:
 ''')
 		in_dir = xpath
 		xpath = "".join(input()).strip()
-		c = run.config(in_dir,xpath)
-		run.writeTables(c)
+		c = alac.config(in_dir,xpath)
+		alac.writeTables(c)
 	if info == "N":
 		print(f'''
-			Alacorder completed the task and will now quit.
+Alacorder completed the task and will now quit.
 			''')
